## ---- eval=FALSE---------------------------------------------------------
#  if (!requireNamespace("BiocManager", quietly=TRUE))
#      install.packages("BiocManager")
#  BiocManager::install("sesame")

## ---- eval=FALSE---------------------------------------------------------
#  library(devtools)
#  install_github('zwdzwd/sesameData')
#  install_github('zwdzwd/sesame')

## ------------------------------------------------------------------------
library(sesameData)
library(sesame)
sset <- sesameDataGet('EPIC.1.LNCaP')$sset

## ------------------------------------------------------------------------
sset

## ------------------------------------------------------------------------
head(slot(sset, 'II'))

## ------------------------------------------------------------------------
head(II(sset))

## ------------------------------------------------------------------------
head(IR(sset))
head(oobG(sset))

## ------------------------------------------------------------------------
head(ctl(sset))

## ------------------------------------------------------------------------
IDATprefixes <- searchIDATprefixes(
    system.file("extdata/", package = "sesameData"))
betas <- openSesame(IDATprefixes)

## ------------------------------------------------------------------------
betas <- getBetas(dyeBiasCorrTypeINorm(noob(sset)))

## ------------------------------------------------------------------------
ssets <- lapply(
    searchIDATprefixes(system.file("extdata/", package = "sesameData")),
    readIDATpair)

## ------------------------------------------------------------------------
library(sesame)
sset.dbLinear <- dyeBiasCorr(sset)
qqplot(
    slot(sset.dbLinear, 'IR'), slot(sset.dbLinear, 'IG'),
    xlab='Type-I Red Signal', ylab='Type-I Grn Signal',
    main='Linear Correction', cex=0.5)
abline(0,1,lty='dashed')

## ------------------------------------------------------------------------
sset.dbNonlinear <- dyeBiasCorrTypeINorm(sset)

## ------------------------------------------------------------------------
qqplot(
    slot(sset.dbNonlinear, 'IR'), slot(sset.dbNonlinear, 'IG'),
    xlab='Type-I Red Signal', ylab='Type-I Grn Signal',
    main='Nonlinear Correction', cex=0.5)
abline(0,1,lty='dashed')

## ------------------------------------------------------------------------
betas <- getBetas(sset)
head(betas)

## ------------------------------------------------------------------------
betas <- getBetasTypeIbySumChannels(sset)

## ------------------------------------------------------------------------
extraSNPAFs <- getAFTypeIbySumAlleles(sset)

## ------------------------------------------------------------------------
inferSex(sset)
inferSexKaryotypes(sset)

## ------------------------------------------------------------------------
inferEthnicity(sset)

## ------------------------------------------------------------------------
betas <- sesameDataGet('HM450.1.TCGA.PAAD')$betas
predictAgeHorvath353(betas)

## ------------------------------------------------------------------------
meanIntensity(sset)

## ------------------------------------------------------------------------
bisConversionControl(sset)

## ---- message=FALSE, fig.width=6, fig.height=5---------------------------
betas <- sesameDataGet('HM450.10.TCGA.PAAD.normal')
visualizeGene('DNMT1', betas, platform='HM450')

## ---- message=FALSE, fig.width=6, fig.height=5---------------------------
visualizeRegion(
    'chr19',10260000,10380000, betas, platform='HM450',
    show.probeNames = FALSE)

## ---- message=FALSE, fig.width=6-----------------------------------------
visualizeProbes(c("cg02382400", "cg03738669"), betas, platform='HM450')

## ---- message=FALSE, fig.width=6-----------------------------------------
ssets.normal <- sesameDataGet('EPIC.5.normal')
segs <- cnSegmentation(sset, ssets.normal)

## ---- message=FALSE, fig.width=6-----------------------------------------
visualizeSegments(segs)

## ---- message=FALSE------------------------------------------------------
betas.tissue <- sesameDataGet('HM450.1.TCGA.PAAD')$betas
estimateLeukocyte(betas.tissue)

